import { ConnectionStatus, DocId, SqlValue } from "@orbitinghail/sqlsync-worker";
import { ParameterizedQuery } from "./sql";
export type Row = Record<string, SqlValue>;
export interface DocType<Mutation> {
    readonly reducerUrl: string | URL;
    readonly serializeMutation: (mutation: Mutation) => Uint8Array;
}
export interface QuerySubscription {
    handleRows: (rows: Row[]) => void;
    handleErr: (err: string) => void;
}
export declare class SQLSync {
    #private;
    constructor(workerUrl: string | URL, wasmUrl: string | URL, coordinatorUrl?: string | URL);
    close(): void;
    query<M, T extends Row = Row>(docId: DocId, docType: DocType<M>, sql: string, params: SqlValue[]): Promise<T[]>;
    subscribe<M>(docId: DocId, docType: DocType<M>, query: ParameterizedQuery, subscription: QuerySubscription): Promise<() => void>;
    mutate<M>(docId: DocId, docType: DocType<M>, mutation: M): Promise<void>;
    get connectionStatus(): ConnectionStatus;
    addConnectionStatusListener(listener: (status: ConnectionStatus) => void): () => void;
    setConnectionEnabled<M>(docId: DocId, docType: DocType<M>, enabled: boolean): Promise<void>;
}
